function confidence = detectOutlier(I_warped, I_fixed, refIdx, thresh, winSize, method, outSize)
    
    for k = 1:size(I_warped, 3)  
        if k ~= refIdx          
            % Reorganize image pair to complex array for block processing.
            I = I_warped(:,:,k) + 1j*I_fixed(:,:,k);
            
            if strcmp(method, 'patch')
                % Evaluate patch-wise similarity. Resize confidence map to the
                % desired dimension if required.
                rho_k = imresize( blockproc(I, [winSize, winSize], @ncc), outSize );
            elseif strcmp(method, 'sliding')
                % Evaluate similarity in a sliding window scheme. Resize confidence map to the
                % desired dimension if required.
                rho_k = imresize( nlfilter(I, [winSize, winSize], @ncc), outSize );
            end
            
            % Reject confidence measures below the given threshold.
            rho_k((rho_k < thresh) | (isnan(rho_k))) = 0;
            confidence{k} = imageToVector(rho_k);      
        else
            % Set confidence map to the all-one vector for the reference 
            % frame.
            confidence{k} = ones(outSize(1)*outSize(2), 1);
        end     
    end

function weight = ncc(block)
    
    if isstruct(block)
        block = block.data;
    end
    I1 = double( real(block) );
    I2 = double( imag(block) );
    weight = mean2( (I1 - mean2(I1)) .* (I2 - mean2(I2)) ) ./ (std2(I1) * std2(I2));
    weight = 0.5 * (1 + weight);